@@ -32,7 +32,6 @@ Here is a minimal deployable pattern definition:
 const { EventsRuleToLambdaProps, EventsRuleToLambda } = require('@aws-solutions-constructs/aws-events-rule-lambda');
 
 const props: EventsRuleToLambdaProps = {
-    deployLambda: true,
     lambdaFunctionProps: {
         code: lambda.Code.asset(`${__dirname}/lambda`),
         runtime: lambda.Runtime.NODEJS_12_X,
@@ -62,9 +61,8 @@ new EventsRuleToLambda(scope: Construct, id: string, props: EventsRuleToLambdaPr
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployLambda|`boolean`|Whether to create a new lambda function or use an existing lambda function|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object|
-|lambdaFunctionProps|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user provided props to override the default props for lambda.Function|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |eventRuleProps|[`events.RuleProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.RuleProps.html)|User provided eventRuleProps to override the defaults|
 
 ## Pattern Properties
@@ -113,15 +111,26 @@ import aws_cdk.aws_lambda
 import aws_cdk.core
 
 
-class EventsRuleToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-events-rule-lambda.EventsRuleToLambda"):
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, deploy_lambda: bool, event_rule_props: aws_cdk.aws_events.RuleProps, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+class EventsRuleToLambda(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-solutions-constructs/aws-events-rule-lambda.EventsRuleToLambda",
+):
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        event_rule_props: aws_cdk.aws_events.RuleProps,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+    ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         access:
         :access:: public
@@ -130,7 +139,11 @@ class EventsRuleToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_t
         summary:
         :summary:: Constructs a new instance of the EventsRuleToLambda class.
         """
-        props = EventsRuleToLambdaProps(deploy_lambda=deploy_lambda, event_rule_props=event_rule_props, existing_lambda_obj=existing_lambda_obj, lambda_function_props=lambda_function_props)
+        props = EventsRuleToLambdaProps(
+            event_rule_props=event_rule_props,
+            existing_lambda_obj=existing_lambda_obj,
+            lambda_function_props=lambda_function_props,
+        )
 
         jsii.create(EventsRuleToLambda, self, [scope, id, props])
 
@@ -145,37 +158,44 @@ class EventsRuleToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.get(self, "lambdaFunction")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-events-rule-lambda.EventsRuleToLambdaProps", jsii_struct_bases=[], name_mapping={'deploy_lambda': 'deployLambda', 'event_rule_props': 'eventRuleProps', 'existing_lambda_obj': 'existingLambdaObj', 'lambda_function_props': 'lambdaFunctionProps'})
-class EventsRuleToLambdaProps():
-    def __init__(self, *, deploy_lambda: bool, event_rule_props: aws_cdk.aws_events.RuleProps, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/aws-events-rule-lambda.EventsRuleToLambdaProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "event_rule_props": "eventRuleProps",
+        "existing_lambda_obj": "existingLambdaObj",
+        "lambda_function_props": "lambdaFunctionProps",
+    },
+)
+class EventsRuleToLambdaProps:
+    def __init__(
+        self,
+        *,
+        event_rule_props: aws_cdk.aws_events.RuleProps,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+    ) -> None:
         """
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         summary:
         :summary:: The properties for the CloudFrontToApiGateway Construct
         """
-        if isinstance(event_rule_props, dict): event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
-        if isinstance(lambda_function_props, dict): lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        if isinstance(event_rule_props, dict):
+            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
+        if isinstance(lambda_function_props, dict):
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
+                **lambda_function_props
+            )
         self._values = {
-            'deploy_lambda': deploy_lambda,
-            'event_rule_props': event_rule_props,
+            "event_rule_props": event_rule_props,
         }
-        if existing_lambda_obj is not None: self._values["existing_lambda_obj"] = existing_lambda_obj
-        if lambda_function_props is not None: self._values["lambda_function_props"] = lambda_function_props
-
-    @builtins.property
-    def deploy_lambda(self) -> bool:
-        """Whether to create a new lambda function or use an existing lambda function.
-
-        If set to false, you must provide a lambda function object as ``existingObj``
-
-        default
-        :default: - true
-        """
-        return self._values.get('deploy_lambda')
+        if existing_lambda_obj is not None:
+            self._values["existing_lambda_obj"] = existing_lambda_obj
+        if lambda_function_props is not None:
+            self._values["lambda_function_props"] = lambda_function_props
 
     @builtins.property
     def event_rule_props(self) -> aws_cdk.aws_events.RuleProps:
@@ -184,29 +204,27 @@ class EventsRuleToLambdaProps():
         default
         :default: - None
         """
-        return self._values.get('event_rule_props')
+        return self._values.get("event_rule_props")
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object.
-
-        If ``deploy`` is set to false only then this property is required
+        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         default
         :default: - None
         """
-        return self._values.get('existing_lambda_obj')
+        return self._values.get("existing_lambda_obj")
 
     @builtins.property
-    def lambda_function_props(self) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """Optional user provided props to override the default props.
-
-        If ``deploy`` is set to true only then this property is required
+    def lambda_function_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+        """User provided props to override the default props for the Lambda function.
 
         default
         :default: - Default props are used
         """
-        return self._values.get('lambda_function_props')
+        return self._values.get("lambda_function_props")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -215,7 +233,9 @@ class EventsRuleToLambdaProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'EventsRuleToLambdaProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "EventsRuleToLambdaProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
