@@ -15,7 +15,12 @@ import aws_cdk.core._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-constructs/aws-events-rule-lambda", "1.46.0", __name__[0:-6], "aws-events-rule-lambda@1.46.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-solutions-constructs/aws-events-rule-lambda",
+    "1.49.0",
+    __name__[0:-6],
+    "aws-events-rule-lambda@1.49.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
